package FPauth-strategies

  1. Overview
  2. Docs

Module FPauth_strategies.PasswordSource

Password is a simple authentication strategy which verifies identity via provided in params password.

Requires "password" param, otherwise skipped.

Sourceval name : string

Name of the strategy.

Sourcemodule type MODEL = sig ... end

MODEL contains requirements for user model in order to use the strategy

Sourcemodule Make (M : MODEL) : sig ... end

Make creates a strategy for a provided model.